@@ -2,8 +2,10 @@ use strict;
 use warnings;
 package Dist::Zilla::App::Command::issues;
 # ABSTRACT: Print the count of outstanding RT and github issues for your distribution
-# vim: set ts=8 sts=4 sw=4 tw=78 et :
-our $VERSION = '0.008';
+# vim: set ts=8 sts=4 sw=4 tw=115 et :
+
+our $VERSION = '0.009';
+
 use Dist::Zilla::App -command;
 
 sub abstract { "print your distribution's count of outstanding RT and github issues" }
@@ -62,7 +64,7 @@ Dist::Zilla::App::Command::issues - Print the count of outstanding RT and github
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 SYNOPSIS
 
@@ -108,14 +110,6 @@ C<resources> field in metadata, but can be explicitly passed if your
 distribution's plugins cannot yet determine the repository location (for
 example you haven't configured the git remote spec).
 
-=head1 SUPPORT
-
-=for stopwords irc
-
-Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-CheckIssues>
-(or L<bug-Dist-Zilla-Plugin-CheckIssues@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-CheckIssues@rt.cpan.org>).
-I am also usually active on irc, as 'ether' at C<irc.perl.org>.
-
 =head1 SEE ALSO
 
 =over 4
@@ -126,11 +120,24 @@ L<Dist::Zilla::Plugin::CheckIssues>
 
 =back
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-CheckIssues>
+(or L<bug-Dist-Zilla-Plugin-CheckIssues@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-CheckIssues@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+L<http://dzil.org/#mailing-list>.
+
+There is also an irc channel available for users of this distribution, at
+irc://irc.perl.org/#distzilla.
+
+I am also usually active on irc, as 'ether' at C<irc.perl.org>.
+
 =head1 AUTHOR
 
 Karen Etheridge <ether@cpan.org>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2014 by Karen Etheridge.
 
