@@ -1,10 +1,12 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::CheckIssues; # git description: v0.007-9-g7723491
+package Dist::Zilla::Plugin::CheckIssues; # git description: v0.008-15-g19edd83
 # ABSTRACT: Retrieve count of outstanding RT and github issues for your distribution
 # KEYWORDS: plugin bugs issues rt github
-# vim: set ts=8 sts=4 sw=4 tw=78 et :
-our $VERSION = '0.008';
+# vim: set ts=8 sts=4 sw=4 tw=115 et :
+
+our $VERSION = '0.009';
+
 use Moose;
 with 'Dist::Zilla::Role::BeforeRelease';
 use List::Util 1.33 'none';
@@ -52,6 +54,7 @@ has repo_url => (
     },
 );
 
+# owner_name, repo_name
 has _github_owner_repo => (
     isa => 'ArrayRef[Str]',
     init_arg => undef,
@@ -207,7 +210,7 @@ Dist::Zilla::Plugin::CheckIssues - Retrieve count of outstanding RT and github i
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 SYNOPSIS
 
@@ -261,14 +264,6 @@ option which fetches the actual titles of the open issues. Advice or patches wel
 Possibly other issue trackers? Does anyone even use any other issue trackers
 anymore? :)
 
-=head1 SUPPORT
-
-=for stopwords irc
-
-Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-CheckIssues>
-(or L<bug-Dist-Zilla-Plugin-CheckIssues@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-CheckIssues@rt.cpan.org>).
-I am also usually active on irc, as 'ether' at C<irc.perl.org>.
-
 =head1 ACKNOWLEDGEMENTS
 
 =for stopwords Ricardo Signes codereview
@@ -294,11 +289,24 @@ L<Dist::Zilla::Plugin::AutoMetaResources> - configuration-based resource metadat
 
 =back
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-CheckIssues>
+(or L<bug-Dist-Zilla-Plugin-CheckIssues@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-CheckIssues@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+L<http://dzil.org/#mailing-list>.
+
+There is also an irc channel available for users of this distribution, at
+irc://irc.perl.org/#distzilla.
+
+I am also usually active on irc, as 'ether' at C<irc.perl.org>.
+
 =head1 AUTHOR
 
 Karen Etheridge <ether@cpan.org>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2014 by Karen Etheridge.
 
